@@ -7,7 +7,14 @@ def test_factory_works():
     assert isinstance(tr.createTransport("eth"), tr.BaseTransport)
     assert isinstance(tr.createTransport("sxi"), tr.BaseTransport)
     assert isinstance(
-        tr.createTransport("can", config={"CAN_ID_MASTER": 1, "CAN_ID_SLAVE": 2, "CAN_DRIVER": "MockCanInterface"}),
+        tr.createTransport(
+            "can",
+            config={
+                "CAN_ID_MASTER": 1,
+                "CAN_ID_SLAVE": 2,
+                "CAN_DRIVER": "MockCanInterface",
+            },
+        ),
         tr.BaseTransport,
     )
 
@@ -16,7 +23,14 @@ def test_factory_works_case_insensitive():
     assert isinstance(tr.createTransport("ETH"), tr.BaseTransport)
     assert isinstance(tr.createTransport("SXI"), tr.BaseTransport)
     assert isinstance(
-        tr.createTransport("CAN", config={"CAN_ID_MASTER": 1, "CAN_ID_SLAVE": 2, "CAN_DRIVER": "MockCanInterface"}),
+        tr.createTransport(
+            "CAN",
+            config={
+                "CAN_ID_MASTER": 1,
+                "CAN_ID_SLAVE": 2,
+                "CAN_DRIVER": "MockCanInterface",
+            },
+        ),
         tr.BaseTransport,
     )
 
