@@ -89,9 +89,7 @@ class BaseTransport(metaclass=abc.ABCMeta):
         self.counterSend = 0
         self.counterReceived = -1
         create_daq_timestamps = self.config.get("CREATE_DAQ_TIMESTAMPS")
-        self.create_daq_timestamps = (
-            False if create_daq_timestamps is None else create_daq_timestamps
-        )
+        self.create_daq_timestamps = False if create_daq_timestamps is None else create_daq_timestamps
         timeout = self.config.get("TIMEOUT")
         self.alignment = self.config.get("ALIGNMENT")
         self.timeout = 2.0 if timeout is None else timeout
@@ -165,9 +163,7 @@ class BaseTransport(metaclass=abc.ABCMeta):
             )
         except Empty:
             if not ignore_timeout:
-                raise types.XcpTimeoutError(
-                    "Response timed out (timeout={}s)".format(self.timeout)
-                ) from None
+                raise types.XcpTimeoutError("Response timed out (timeout={}s)".format(self.timeout)) from None
             else:
                 self.timing.stop()
                 return
@@ -256,9 +252,7 @@ class BaseTransport(metaclass=abc.ABCMeta):
                 block_response += partial_response[1:]
             else:
                 if time() - start > self.timeout:
-                    raise types.XcpTimeoutError(
-                        "Response timed out [block_receive]."
-                    ) from None
+                    raise types.XcpTimeoutError("Response timed out [block_receive].") from None
                 sleep(0.001)
         return block_response
 
@@ -286,11 +280,7 @@ class BaseTransport(metaclass=abc.ABCMeta):
 
     def processResponse(self, response, length, counter, recv_timestamp=None):
         if counter == self.counterReceived:
-            self.logger.warn(
-                "Duplicate message counter {} received from the XCP slave".format(
-                    counter
-                )
-            )
+            self.logger.warn("Duplicate message counter {} received from the XCP slave".format(counter))
             if self._debug:
                 self.logger.debug(
                     "<- L{} C{} {}".format(
@@ -357,11 +347,7 @@ def createTransport(name, *args, **kws):
     if name in transports:
         transportClass = transports[name]
     else:
-        raise ValueError(
-            "'{}' is an invalid transport -- please choose one of [{}].".format(
-                name, " | ".join(transports.keys())
-            )
-        )
+        raise ValueError("'{}' is an invalid transport -- please choose one of [{}].".format(name, " | ".join(transports.keys())))
     return transportClass(*args, **kws)
 
 
